Hook Specifications
===============================

.. currentmodule:: tylisten

Hook Defination
---------------------------

.. autoclass:: tylisten.StaticHookSpec
    :members:
    :special-members: __call__

.. automodule:: tylisten
    :members: hookdef, null_emitter

Basic Hook Instance
-------------------------------

.. autoclass:: tylisten.HookSpec
    :members:
    :special-members: __call__

Hook Instance with Timeout
----------------------------------

.. autoclass:: tylisten.TimeoutHookSpec
    :members:
